﻿using System;
using System.Diagnostics.CodeAnalysis;

// Note: There should be 9 code analysis warnings.

[assembly: SuppressMessage("Spelling", "DF1000:CheckSpellingOfAllStringLiterals", MessageId = "globl", Scope = "member", Target = "ConsoleApplication.Program.#GlobalSuppression()")]

namespace ConsoleApplication
{
    class Program
    {
        private const string _null = null;

        private const string _const = "cnst";

        private static string _static = "statc";

        private static string Property
        {
            get { return "proprty"; }
        }

        static void Main()
        {
            Example();
            SingleInstance();
            CodeLiterals();
            GlobalSuppression();
            MultipleInstancesA();
            MultipleInstancesB();
            DuplicatesInString();
            Console.WriteLine(_static);
            Console.WriteLine(Property);
            Console.WriteLine(new SubProgram());
        }

        private string _member = "membr";

        public Program(string parameter = "param")
        {
            Console.WriteLine(parameter);
            Console.WriteLine(_member);
        }

        static void Example()
        {
            WriteLine("This string has an example misspelling: mispelling");
        }

        [SuppressMessage("Spelling", "DF1000:CheckSpellingOfAllStringLiterals", MessageId = "leet", Justification = "Jargon.")]
        static void SingleInstance()
        {
            WriteLine("This string correctly uses a word not in the dictionary: leet");
        }

        [SuppressMessage("Spelling", "DF1000:CheckSpellingOfAllStringLiterals", Justification = "Code is not misspelled; no words in this method.")]
        static void CodeLiterals()
        {
            WriteLine("int i = 0;");
            WriteLine("printf(i);");
        }

        static void GlobalSuppression()
        {
            WriteLine("This misspelling is addressed at the global level: globl");
        }

        static void MultipleInstancesA()
        {
            WriteLine("This word is in the custom dictionary: kustom");
        }

        static void MultipleInstancesB()
        {
            WriteLine("This word is in the custom dictionary: kustom");
        }

        static void DuplicatesInString()
        {
            WriteLine("This word appears multiple times: multple multple multple");
        }

        static void WriteLine(string s)
        {
            Console.WriteLine(s);
        }
    }

    class SubProgram : Program
    {
        public SubProgram()
            : base("subb")
        {
        }
    }
}
